@@ -12,7 +12,6 @@
 -module(rexi_buffer).
 
 -behaviour(gen_server).
--vsn(1).
 
 %  gen_server callbacks
 -export([
@@ -20,40 +19,57 @@
     handle_call/3,
     handle_cast/2,
     handle_info/2,
-    terminate/2,
-    code_change/3
+    terminate/2
 ]).
 
 -export([
     send/2,
-    start_link/1
+    start_link/1,
+    get_buffered_count/1,
+    erase_buffer/1
 ]).
 
+-define(BUFFER_COUNT_DEFAULT, 2000).
+-define(COUNTER, counter).
+
 -record(state, {
+    server_id,
     buffer = queue:new(),
     sender = nil,
     count = 0,
+    counter,
     max_count
 }).
 
 start_link(ServerId) ->
-    gen_server:start_link({local, ServerId}, ?MODULE, nil, []).
+    gen_server:start_link({local, ServerId}, ?MODULE, [ServerId], []).
 
 send(Dest, Msg) ->
     Server = list_to_atom(lists:concat([rexi_buffer, "_", get_node(Dest)])),
     gen_server:cast(Server, {deliver, Dest, Msg}).
 
-init(_) ->
+get_buffered_count(ServerId) when is_atom(ServerId) ->
+    case persistent_term:get(counter_key(ServerId), undefined) of
+        undefined -> 0;
+        Ref -> counters:get(Ref, 1)
+    end.
+
+erase_buffer(ServerId) ->
+    gen_server:call(ServerId, erase_buffer, infinity).
+
+init([ServerId]) ->
     %% TODO Leverage os_mon to discover available memory in the system
-    Max = list_to_integer(config:get("rexi", "buffer_count", "2000")),
-    {ok, #state{max_count = Max}}.
+    Counter = counters:new(1, []),
+    persistent_term:put(counter_key(ServerId), Counter),
+    Max = config:get_integer("rexi", "buffer_count", ?BUFFER_COUNT_DEFAULT),
+    {ok, #state{server_id = ServerId, max_count = Max, counter = Counter}}.
 
-handle_call(erase_buffer, _From, State) ->
-    {reply, ok, State#state{buffer = queue:new(), count = 0}, 0};
-handle_call(get_buffered_count, _From, State) ->
-    {reply, State#state.count, State, 0}.
+handle_call(erase_buffer, _From, #state{counter = Counter} = State) ->
+    counters:put(Counter, 1, 0),
+    {reply, ok, State#state{buffer = queue:new(), count = 0}, 0}.
 
-handle_cast({deliver, Dest, Msg}, #state{buffer = Q, count = C} = State) ->
+handle_cast({deliver, Dest, Msg}, #state{} = State) ->
+    #state{counter = Counter, buffer = Q, count = C} = State,
     couch_stats:increment_counter([rexi, buffered]),
     Q2 = queue:in({Dest, Msg}, Q),
     case should_drop(State) of
@@ -61,15 +77,17 @@ handle_cast({deliver, Dest, Msg}, #state{buffer = Q, count = C} = State) ->
             couch_stats:increment_counter([rexi, dropped]),
             {noreply, State#state{buffer = queue:drop(Q2)}, 0};
         false ->
+            counters:add(Counter, 1, 1),
             {noreply, State#state{buffer = Q2, count = C + 1}, 0}
     end.
 
 handle_info(timeout, #state{sender = nil, buffer = {[], []}, count = 0} = State) ->
     {noreply, State};
 handle_info(timeout, #state{sender = nil, count = C} = State) when C > 0 ->
-    #state{buffer = Q, count = C} = State,
+    #state{counter = Counter, buffer = Q} = State,
     {{value, {Dest, Msg}}, Q2} = queue:out_r(Q),
     NewState = State#state{buffer = Q2, count = C - 1},
+    counters:add(Counter, 1, -1),
     case erlang:send(Dest, Msg, [noconnect, nosuspend]) of
         ok when C =:= 1 ->
             % We just sent the last queued messsage, we'll use this opportunity
@@ -89,15 +107,10 @@ handle_info(timeout, State) ->
 handle_info({'DOWN', Ref, _, Pid, _}, #state{sender = {Pid, Ref}} = State) ->
     {noreply, State#state{sender = nil}, 0}.
 
-terminate(_Reason, _State) ->
+terminate(_Reason, #state{server_id = ServerId}) ->
+    persistent_term:erase(counter_key(ServerId)),
     ok.
 
-code_change(_OldVsn, {state, Buffer, Sender, Count}, _Extra) ->
-    Max = list_to_integer(config:get("rexi", "buffer_count", "2000")),
-    {ok, #state{buffer = Buffer, sender = Sender, count = Count, max_count = Max}};
-code_change(_OldVsn, State, _Extra) ->
-    {ok, State}.
-
 should_drop(#state{count = Count, max_count = Max}) ->
     Count >= Max.
 
@@ -105,3 +118,6 @@ get_node({_, Node}) when is_atom(Node) ->
     Node;
 get_node(Pid) when is_pid(Pid) ->
     node(Pid).
+
+counter_key(ServerId) when is_atom(ServerId) ->
+    {?MODULE, ?COUNTER, ServerId}.
