@@ -12,21 +12,16 @@
 
 -module(rexi_server).
 -behaviour(gen_server).
--vsn(1).
 -export([
     init/1,
     handle_call/3,
     handle_cast/2,
     handle_info/2,
-    terminate/2,
-    code_change/3
+    terminate/2
 ]).
 
 -export([start_link/1, init_p/2, init_p/3]).
 
-% for the stacktrace macro only so far
--include_lib("couch/include/couch_db.hrl").
-
 -include_lib("rexi/include/rexi.hrl").
 
 -record(job, {
@@ -84,6 +79,9 @@ handle_cast({doit, {ClientPid, ClientRef} = From, Nonce, MFA}, State) ->
     },
     {noreply, add_job(Job, State)};
 handle_cast({kill, FromRef}, St) ->
+    % TODO: Compatibility clause. This is left to handle mixed cluster
+    % upgrades. Old nodes may still send {kill, Ref} message from rexi:kill.
+    % Remove in somme future 3.4+ version.
     kill_worker(FromRef, St),
     {noreply, St};
 handle_cast({kill_all, FromRefs}, St) ->
@@ -126,9 +124,6 @@ terminate(_Reason, St) ->
     ),
     ok.
 
-code_change(_OldVsn, #st{} = State, _Extra) ->
-    {ok, State}.
-
 init_p(From, MFA) ->
     init_p(From, MFA, undefined).
 
